<?php
require_once('validator.php');

class inquiry_form_validator extends InquiryValidator{
	public static function textbox($element, &$errmsg = array()) {

		$validation = $element['field_validation'];
		$validation = explode(',', $validation);
	
		$target = array();
		$target['req']    = $validation[0];
		$target['len']    = $validation[1];
		$target['zen']    = $validation[2];
		$target['eiji']   = $validation[3];
		$target['number'] = $validation[4];
		$target['seiki']  = $validation[5];
		$errmsg[$element['field_name']] = array();

		//必須チェック
		if ($target['req'] === 'req' && !self::required($_POST[$element['field_name']])) {
			$errmsg[$element['field_name']][] = $element['field_subject'].InquiryValidatorMessage::REQUIRED;
		}

		//長さチェック
		if ($target['len'] != "" && !self::maxlength($_POST[$element['field_name']], $target['len'])) {
			$errmsg[$element['field_name']][] = $element['field_subject'].str_replace('__maxlength__', $target['len'], InquiryValidatorMessage::MAXLENGTH);
		}

		//半角のみ
		if ($target['zen'] === 'zen' && $target['eiji'] !== 'eiji' && $target['number'] !== 'number' && self::isZenkaku($_POST[$element['field_name']])) {
			$errmsg[$element['field_name']][] = $element['field_subject'].InquiryValidatorMessage::HANKAKU;
		}

		//半角数字のみ
		if ($target['zen'] === 'zen' && $target['eiji'] === 'eiji' && !self::isNumber($_POST[$element['field_name']])) {
			$errmsg[$element['field_name']][] = $element['field_subject'].InquiryValidatorMessage::NUMBER;
		}

		//半角英字のみ
		if ($target['zen'] === 'zen' && $target['number'] === 'number' && !self::isAlpha($_POST[$element['field_name']])) {
			$errmsg[$element['field_name']][] = $element['field_subject'].InquiryValidatorMessage::EIJI;
		}
		
		//全角のみ
		if ($target['eiji'] === 'eiji' && $target['number'] === 'number' && !self::isZenkaku($_POST[$element['field_name']])) {
			$errmsg[$element['field_name']][] = $element['field_subject'].InquiryValidatorMessage::ZENKAKU;
		}
		
		//確認用入力フォームと突き合わせ
		if ($_POST[$element['field_name']] != '' && $element['field_option'] === 'confirm' && !self::check_confirm($_POST[$element['field_name']], $_POST['confirm-'.$element['field_name']])) {
			$errmsg[$element['field_name']][] = $element['field_subject'].InquiryValidatorMessage::CONFIRM;
		}
	}
	
	public static function radio($element, &$errmsg = array()) {

		$validation = $element['field_validation'];
		$validation = explode(',', $validation);

		$target = array();
		$target['req']    = $validation[0];
		$errmsg[$element['field_name']] = array();
		//必須チェック
		if ($target['req'] === 'req' && !self::required($_POST[$element['field_name']])) {
			$errmsg[$element['field_name']][] = $element['field_subject'].InquiryValidatorMessage::REQUIRED_SELECT;
		}
	}
	
	public static function selectbox($element, &$errmsg = array()) {
		$validation = $element['field_validation'];
		$validation = explode(',', $validation);
	
		$target = array();
		$target['req']    = $validation[0];
		$errmsg[$element['field_name']] = array();
		//必須チェック
		if ($target['req'] === 'req' && (!self::required($_POST[$element['field_name']]) || $_POST[$element['field_name']] === 'default')) {
			$errmsg[$element['field_name']][] = $element['field_subject'].InquiryValidatorMessage::REQUIRED_SELECT;
		}
	}
	
	public static function checkbox($element, &$errmsg = array()) {

		$validation = $element['field_validation'];
		$validation = explode(',', $validation);

		$target = array();
		$target['req']    = $validation[0];
		$errmsg[$element['field_name']] = array();
		//必須チェック
		if ($target['req'] === 'req' && !array_key_exists($element['field_name'], $_POST)) {
			$errmsg[$element['field_name']][] = $element['field_subject'].InquiryValidatorMessage::REQUIRED_SELECT;
		}
	}
	
	public static function email($element, &$errmsg = array()) {

		$validation = $element['field_validation'];
		$validation = explode(',', $validation);

		$errmsg[$element['field_name']] = array();

		//必須チェック
		if ($validation[0] === 'req' && !self::required($_POST[$element['field_name']])) {
			$errmsg[$element['field_name']][0] = $element['field_subject'].InquiryValidatorMessage::REQUIRED;
		}
		
		//半角英数記号チェック
		if ($_POST[$element['field_name']] != '' && $validation[1] === 'han' && !self::check_mail($_POST[$element['field_name']])) {
			$errmsg[$element['field_name']][1] = $element['field_subject'].InquiryValidatorMessage::KEISHIKI;
		}

		//簡易チェック
		if ($_POST[$element['field_name']] != '' && $validation[2] === 'split' && !self::check_mail($_POST[$element['field_name']], 'NOTRFC')) {
			$errmsg[$element['field_name']][1] = $element['field_subject'].InquiryValidatorMessage::KEISHIKI;
		}

		//厳密チェック
		if ($_POST[$element['field_name']] != '' && $validation[3] === 'splitrfc' && !self::check_mail($_POST[$element['field_name']], 'RFC')) {
			$errmsg[$element['field_name']][1] = $element['field_subject'].InquiryValidatorMessage::KEISHIKI;
		}

		//Aレコード
		if ($_POST[$element['field_name']] != '' && $validation[4] === 'domain' && !self::check_dns_record($_POST[$element['field_name']], 'A')) {
			$errmsg[$element['field_name']][1] = $element['field_subject'].InquiryValidatorMessage::KEISHIKI;
		}
		
		//MXレコード
		if ($_POST[$element['field_name']] != '' && $validation[5] === 'mx' && !self::check_dns_record($_POST[$element['field_name']], 'MX')) {
			$errmsg[$element['field_name']][1] = $element['field_subject'].InquiryValidatorMessage::KEISHIKI;
		}
		
		//禁止ドメインチェック
		if ($_POST[$element['field_name']] != '' && $validation[6] != '') {
			$validation[6] = explode("\n", $validation[6]);
			$mail = explode('@', $_POST[$element['field_name']]);
			if (!self::check_list($mail[1], $validation[6])) {
				$errmsg[$element['field_name']][2] = $element['field_subject'].str_replace('__banned__', $_POST[$element['field_name']], InquiryValidatorMessage::BANNED);
			}
		}
		
		//確認フォームとの突合せチェック
		if ($_POST[$element['field_name']] != '' && $element['field_option'] === 'confirm' && !self::check_confirm($_POST[$element['field_name']], $_POST['confirm-'.$element['field_name']])) {
			$errmsg[$element['field_name']][3] = $element['field_subject'].InquiryValidatorMessage::CONFIRM;
		}
	}
	
	public static function tel($element, &$errmsg = array()) {
		$validation = $element['field_validation'];
		$validation = explode(',', $validation);

		$errmsg[$element['field_name']] = array();
		
		switch($element['field_option']) {
			case 0: //ハイフン付き
				$post = $_POST[$element['field_name'].'-1'].$_POST[$element['field_name'].'-2'].$_POST[$element['field_name'].'-3'];
				//必須チェック
				if ($validation[0] === 'req' && (!self::required($_POST[$element['field_name'].'-1']) || !self::required($_POST[$element['field_name'].'-2']) || !self::required($_POST[$element['field_name'].'-3'])) ) {
					$errmsg[$element['field_name']][0] = $element['field_subject'].InquiryValidatorMessage::REQUIRED;
				}
				
				//数値チェック
				if ($post != '' && $validation[1] === 'number' && (!self::isNumber($_POST[$element['field_name'].'-1']) || !self::isNumber($_POST[$element['field_name'].'-2']) || !self::isNumber($_POST[$element['field_name'].'-3']) ) ) {
					$errmsg[$element['field_name']][1] = $element['field_subject'].InquiryValidatorMessage::NUMBER;
				}
				
				//固定電話チェック
				if ($post != '' && $validation[2] === 'phone' && $validation[3] !== 'mobile' && !self::is_phone_exact($_POST[$element['field_name'].'-1'], $_POST[$element['field_name'].'-2'], $_POST[$element['field_name'].'-3'])) {
					$errmsg[$element['field_name']][2] = $element['field_subject'].InquiryValidatorMessage::KEISHIKI;
				}
				
				//携帯電話チェック
				if ($post != '' && $validation[3] === 'mobile' && $validation[2] !== 'phone' && !self::is_mobile_exact($_POST[$element['field_name'].'-1'], $_POST[$element['field_name'].'-2'], $_POST[$element['field_name'].'-3'])) {
					$errmsg[$element['field_name']][2] = $element['field_subject'].InquiryValidatorMessage::KEISHIKI;
				}
				
				//固定電話または携帯電話
				if ($post != '' && $validation[3] === 'mobile' && $validation[2] === 'phone' && !self::is_mobile_exact($_POST[$element['field_name'].'-1'], $_POST[$element['field_name'].'-2'], $_POST[$element['field_name'].'-3']) && !self::is_phone_exact($_POST[$element['field_name'].'-1'], $_POST[$element['field_name'].'-2'], $_POST[$element['field_name'].'-3']) ) {
					$errmsg[$element['field_name']][2] = $element['field_subject'].InquiryValidatorMessage::KEISHIKI;
				}
				
				//禁止ドメインチェック
				if ($post != '' && $validation[4] != '') {
					$validation[4] = explode("\n", $validation[4]);
					if (!self::check_list($post, $validation[4])) {
						$errmsg[$element['field_name']][3] = $element['field_subject'].str_replace('__banned__', $_POST[$element['field_name']], InquiryValidatorMessage::BANNED);
					}
				}
				break;
				
				
			case 1:
			
				//必須チェック
				if ($validation[0] === 'req' && !self::required($_POST[$element['field_name']])) {
					$errmsg[$element['field_name']][0] = $element['field_subject'].InquiryValidatorMessage::REQUIRED;
				}
				
				//数値チェック
				if ($_POST[$element['field_name']] != '' && $validation[1] === 'number' && !self::isNumber($_POST[$element['field_name']])) {
					$errmsg[$element['field_name']][1] = $element['field_subject'].InquiryValidatorMessage::NUMBER;
				}
				
				//固定電話チェック
				if ($_POST[$element['field_name']] != '' && $validation[2] === 'phone' && $validation[3] !== 'mobile' && !self::is_phone_easy($_POST[$element['field_name']])) {
					$errmsg[$element['field_name']][2] = $element['field_subject'].InquiryValidatorMessage::KEISHIKI;
				}
				
				//携帯電話チェック
				if ($_POST[$element['field_name']] != '' && $validation[3] === 'mobile' && $validation[2] !== 'phone' && !self::is_mobile_easy($_POST[$element['field_name']])) {
					$errmsg[$element['field_name']][2] = $element['field_subject'].InquiryValidatorMessage::KEISHIKI;
				}
				
				//固定電話または携帯電話
				if ( $_POST[$element['field_name']] != '' && $validation[3] === 'mobile' && $validation[2] === 'phone' && !self::is_mobile_easy($_POST[$element['field_name']]) && !self::is_phone_easy($_POST[$element['field_name']]) ) {
					$errmsg[$element['field_name']][2] = $element['field_subject'].InquiryValidatorMessage::KEISHIKI;
				}
				
				//禁止ドメインチェック
				if ($_POST[$element['field_name']] != '' && $validation[4] != '') {
					$validation[4] = explode("\n", $validation[4]);
					if (!self::check_list($_POST[$element['field_name']], $validation[4])) {
						$errmsg[$element['field_name']][3] = $element['field_subject'].str_replace('__banned__', $_POST[$element['field_name']], InquiryValidatorMessage::BANNED);
					}
				}
				break;
		}
	}
}